@@ -24,9 +24,11 @@ class Network3Medusa():
             json_dict = json.loads(raw_json)
             for interface in enumerate(json_dict):
                 if interface == 0:
+                    print("first")
                     raw_json=interface
                     self.add_file_to_hedera(raw_json)
                 else:
+                    print("not first")
                     raw_json=interface
                     self.append_file_to_hedera(raw_json)
             print(self.receipt.toString())
